==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebGridToolbarPinningDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseToolbarColumnActionsDirectiveDescriptionMetadata } from "./WebBaseToolbarColumnActionsDirectiveDescriptionMetadata";
import { WebGridToolbarPinningDescription } from "./WebGridToolbarPinningDescription";
/**
 * @hidden
 */
export let WebGridToolbarPinningDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridToolbarPinningDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridToolbarPinningDescriptionMetadata.a == null) {
                WebGridToolbarPinningDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridToolbarPinningDescriptionMetadata.c(WebGridToolbarPinningDescriptionMetadata.a);
            }
            if (a.j(WebGridToolbarPinningDescriptionMetadata.a)) {
                return;
            }
            a.y(WebGridToolbarPinningDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:GridToolbarPinning");
            a.item("__tagNameWC", "String:igc-grid-toolbar-pinning");
            a.item("__packageNameWC", "String:grids");
            a.item("__manageItemInMarkup", "Boolean");
        }
        static d(a) {
            WebGridToolbarPinningDescriptionMetadata.b(a);
            a.aa("WebGridToolbarPinning", () => new WebGridToolbarPinningDescription());
            a.z("WebGridToolbarPinning", WebGridToolbarPinningDescriptionMetadata.a);
        }
    }
    WebGridToolbarPinningDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridToolbarPinningDescriptionMetadata, 'WebGridToolbarPinningDescriptionMetadata');
    WebGridToolbarPinningDescriptionMetadata.a = null;
    return WebGridToolbarPinningDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGridToolbarPinningDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseToolbarColumnActionsDirectiveDescriptionMetadata } from "./WebBaseToolbarColumnActionsDirectiveDescriptionMetadata";
import { WebGridToolbarPinningDescription } from "./WebGridToolbarPinningDescription";
/**
 * @hidden
 */
export let WebGridToolbarPinningDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridToolbarPinningDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridToolbarPinningDescriptionMetadata.a == null) {
                WebGridToolbarPinningDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridToolbarPinningDescriptionMetadata.c(WebGridToolbarPinningDescriptionMetadata.a);
            }
            if (a.k(WebGridToolbarPinningDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebGridToolbarPinningDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:GridToolbarPinning");
            a.item("__tagNameWC", "String:igc-grid-toolbar-pinning");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            if (a.containsKey("__skipSuffix")) {
                a.removeItem("__skipSuffix");
            }
            a.item("__manageItemInMarkup", "Boolean");
        }
        static d(a) {
            WebGridToolbarPinningDescriptionMetadata.b(a);
            a.ac("WebGridToolbarPinning", () => new WebGridToolbarPinningDescription());
            a.ab("WebGridToolbarPinning", WebGridToolbarPinningDescriptionMetadata.a);
        }
    }
    WebGridToolbarPinningDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridToolbarPinningDescriptionMetadata, 'WebGridToolbarPinningDescriptionMetadata');
    WebGridToolbarPinningDescriptionMetadata.a = null;
    return WebGridToolbarPinningDescriptionMetadata;
})();
